@@ -16,9 +16,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#ifndef _CHILD_H_
+#define _CHILD_H_
+
 #include <sys/types.h>
 #include <glib.h>
 
+#ifdef __cplusplus
+extern "C" {
+#pragma }
+#endif /* __cplusplus */
+
 int  start_child (char        *cmd,
 		  char       **arg,
 		  GIOChannel **read_chan,
@@ -31,4 +39,12 @@ void write_child (GIOChannel  *write_chan,
 
 int  stop_child  (pid_t        childpid);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* _CHILD_H_ */
+
+
+
 
